apache-airflow-providers-nomad
=============================================

Release: 0.0.4

Airflow Nomad Provider
---------------------------

*Note: This package is not part of the official Apache Airflow Release.*

Provider for `HashiCorp Nomad <https://developer.hashicorp.com/nomad>`__ clusters running Airflow tasks.

The project is in an early stage, and it's going through active development.

For details see the local `Airflow generated documentation <https://juditnovak.github.io/airflow-provider-nomad/>`__
